@@ -1,6 +1,6 @@
 from contextlib import contextmanager
 from datetime import datetime
-from json import loads as from_json
+from json import loads as _from_json
 from json.decoder import JSONDecodeError
 from pathlib import Path
 from random import sample
@@ -15,11 +15,17 @@ from pika import BlockingConnection
 from pika.adapters.blocking_connection import BlockingChannel
 from pika.exceptions import AMQPError, AMQPConnectionError
 from pydantic import BaseModel  # pylint: disable=E0611
+from tenacity import (
+    retry_if_exception_type,
+    stop_after_attempt,
+    wait_random,
+    Retrying,
+)
 from typeguard import typechecked
 
 from robotnikmq.config import RobotnikConfig, config_of
 from robotnikmq.error import UnableToConnect, MalformedMessage
-from robotnikmq.utils import to_json
+from robotnikmq.utils import to_json as _to_json
 
 AMQPErrorCallback = Optional[Callable[[AMQPError], None]]
 ConnErrorCallback = Optional[Callable[[AMQPConnectionError], None]]
@@ -37,7 +43,7 @@ def thread_name(name: Union[str, UUID]):
 @typechecked
 def jsonable(content: Any) -> bool:
     try:
-        to_json(content)
+        _to_json(content)
         return True
     except (TypeError, OverflowError):
         return False
@@ -46,7 +52,7 @@ def jsonable(content: Any) -> bool:
 @typechecked
 def valid_json(string: str) -> bool:
     try:
-        from_json(string)
+        _from_json(string)
         return True
     except JSONDecodeError:
         return False
@@ -79,13 +85,13 @@ class Message:
 
     @typechecked
     def to_json(self) -> str:
-        return to_json(self.to_dict())
+        return _to_json(self.to_dict())
 
     @staticmethod
     @typechecked
     def of(body: str) -> "Message":  # pylint: disable=C0103
         try:
-            msg = from_json(body)
+            msg = _from_json(body)
             return Message(
                 msg["contents"], msg["routing_key"], msg["timestamp"], msg["msg_id"]
             )
@@ -152,7 +158,17 @@ class Robotnik:
     @property
     def connection(self) -> BlockingConnection:
         if self._connection is None or not self._connection.is_open:
-            self._connection = self._make_connection()
+            for attempt in Retrying(
+                retry=retry_if_exception_type((UnableToConnect, AMQPError, OSError)),
+                stop=stop_after_attempt(self.config.connection.attempts),
+                wait=wait_random(
+                    min=self.config.connection.wait_random_min_seconds,
+                    max=self.config.connection.wait_random_max_seconds,
+                ),
+                reraise=True,
+            ):
+                with attempt:
+                    self._connection = self._make_connection()
         return self._connection
 
     @typechecked
